@@ -45,8 +45,7 @@ default_args = [
 import site
 
 teste =site.getsitepackages()
-DOWNLOADS_FOLDER = Path(site.getsitepackages()[1]) /'chromium_binary_lambda'/ 'local-chromium'
-DOWNLOADS_FOLDER.mkdir(parents=True, exist_ok=True)
+DOWNLOADS_FOLDER = Path(site.getsitepackages()[1]) /'chromium_binary_lambda'
 DOWNLOAD_HOST = 'https://storage.googleapis.com'
 BASE_URL = f'{DOWNLOAD_HOST}/chromium-browser-snapshots'
 
